@@ -34,7 +34,7 @@ your system yet, you should install openssh >= 3.8p1
 The Probe asks the given host n-times for it's public key, where n is
 the amount specified in the config File.
 
-As part of the initialization, the probe asks localhost for it's public key
+As part of the initialization, the probe asks 127.0.0.1 for it's public key
 and tries to parse the output. Make sure you have SSH running on the
 localhost as well.
 DOC
@@ -55,7 +55,7 @@ sub new($$$)
     # no need for this if we run as a cgi
     unless ( $ENV{SERVER_SOFTWARE} ) {
         
-        my $call = "$self->{properties}{binary} -t dsa,rsa,rsa1 localhost";
+        my $call = "$self->{properties}{binary} -t dsa,rsa,rsa1 127.0.0.1";
         my $return = `$call 2>&1`;
         if ($return =~ m/$ssh_re/s){
             print "### parsing ssh-keyscan output...OK\n";
@@ -82,13 +82,13 @@ sub pingone ($){
 
     my $host = $target->{addr};
 
-    my $query = "$self->{properties}{binary} -t $target->{vars}->{keytype} $host";
+    my $query = "$self->{properties}{binary} -t $target->{vars}->{keytype}  -p $target->{vars}->{port} $host";
     my @times;
 
     # get the user and system times before and after the test
     $self->do_debug("query=$query\n");
     for (my $run = 0; $run < $self->pings; $run++) {
-       my $t0 = [gettimeofday];
+       my $t0 = [gettimeofday()];
 
 	my $pid = open3($inh,$outh,$errh, $query);
        while (<$errh>) {
@@ -129,10 +129,16 @@ sub targetvars {
         my $class = shift;
         return $class->_makevars($class->SUPER::targetvars, {
            keytype => {
-               _doc => "Type of key, used in ssh-keyscan -t <keytype>",
-	       _re => "[dt]sa1*",
+               _doc => "Type of key, used in ssh-keyscan -t I<keytype>",
+	       _re => "[dr]sa1*",
                _example => 'dsa',
-                _default => 'rsa',
+               _default => 'rsa',
+           },
+           port => {
+               _doc => "Port to use when testing the ssh connection -p I<port>",
+	       _re => '\d+',
+               _example => '5000',
+               _default => '22',
            },
        })
 }
